# Changelog

## 0.1.1

Released 2025-04-05

- Set up CI using GitHub Actions:
  - Run tests
  - Publish to PyPI

## 0.1.0

Released 2025-04-02

- Models and API Client for the following domain
  - instrument
  - order
  - pricing
  - transaction
- Converter function for strats pricing model
